Description: Beer Making Kits from Brooklyn Brew Shop
Keywords: beer making kits, homebrew, craft beer

- Account
- Cart
- Checkout
- Log In

## Beer Making Kits

Choose your style. Our Beer Making Kits are reusable and include the equipment and ingredients for one batch of beer.

##### Hard Cider Kit $40.00 Add to Cart NEW! Make tart, dry and bubbly hard cider!

##### Evil Twin Bikini Beer

$40.00
Add to Cart
Easy-Drinking, Fresh & Hoppy Collaboration with Evil Twin

##### Everyday IPA

$40.00
Add to Cart
Loaded with Citrusy Hops, Balanced Malt-Backbone

##### Bruxelles Blonde

$40.00
Add to Cart
Belgian-Style Blonde Ale, Light & Crisp Hop Aroma

##### Jalapeno Saison

$40.00
Add to Cart
Spicy! Light in Body, Belgian-Style Ale

##### Grapefruit Honey Ale

$40.00
Add to Cart
Bright, Citrusy, With a Touch of Wheat

##### Summer Wheat

$40.00

Special Price $32.00

Add to Cart
Light-Bodied, Spicy & Refreshing